@@ -86,7 +86,11 @@ class BaseRouteHandler(Generic[T]):
         self.opt: Dict[str, Any] = opt or {}
         self.owner: Optional[Union["Controller", "Router"]] = None
         self.signature_model: Optional[Type["SignatureModel"]] = None
-        self.paths = {normalize_path(p) for p in path} if path and isinstance(path, list) else {normalize_path(path or "/")}  # type: ignore
+        self.paths = (
+            {normalize_path(p) for p in path}
+            if path and isinstance(path, list)
+            else {normalize_path(path or "/")}  # type: ignore
+        )
 
     @property
     def dependency_name_set(self) -> Set[str]:
