@@ -39,6 +39,7 @@ from starlite.exceptions import (
     ValidationException,
 )
 from starlite.handlers.base import BaseRouteHandler
+from starlite.openapi.datastructures import ResponseSpec
 from starlite.plugins import get_plugin_for_value
 from starlite.provide import Provide
 from starlite.response import Response
@@ -137,7 +138,9 @@ def _create_response_container_handler(
     async def handler(data: ResponseContainer, app: "Starlite", **kwargs: Any) -> StarletteResponse:
         normalized_headers = {**_normalize_headers(headers), **data.headers}
         normalized_cookies = _normalize_cookies(data.cookies, cookies)
-        response = data.to_response(app=app, headers=normalized_headers, status_code=status_code, media_type=media_type)
+        response = data.to_response(
+            app=app, headers=normalized_headers, status_code=status_code, media_type=data.media_type or media_type
+        )
         for cookie in normalized_cookies:
             response.set_cookie(**cookie)
         return await after_request(response) if after_request else response  # type: ignore
@@ -228,6 +231,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         "response_cookies",
         "response_description",
         "response_headers",
+        "responses",
         "security",
         "status_code",
         "summary",
@@ -269,6 +273,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        responses: Optional[Dict[int, ResponseSpec]] = None,
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
@@ -310,6 +315,8 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
             response_headers: A string keyed dictionary mapping [ResponseHeader][starlite.datastructures.ResponseHeader]
                 instances.
+            responses: A dictionary of additional status codes and a description of their expected content.
+                This information will be included in the OpenAPI schema
             status_code: An http status code for the response. Defaults to '200' for mixed method or 'GET', 'PUT' and
                 'PATCH', '201' for 'POST' and '204' for 'DELETE'.
             sync_to_thread: A boolean dictating whether the handler function will be executed in a worker thread or the
@@ -374,6 +381,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         self.summary = summary
         self.tags = tags
         self.security = security
+        self.responses = responses
         # memoized attributes, defaulted to Empty
         self._resolved_after_response: Union[Optional[AfterResponseHookHandler], EmptyType] = Empty
         self._resolved_before_request: Union[Optional[BeforeRequestHookHandler], EmptyType] = Empty
@@ -492,7 +500,6 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             response_class = self.resolve_response_class()
             headers = self.resolve_response_headers()
             cookies = self.resolve_response_cookies()
-
             if is_class_and_subclass(self.signature.return_annotation, ResponseContainer):  # type: ignore[misc]
                 handler = _create_response_container_handler(
                     after_request=after_request,
@@ -617,6 +624,7 @@ class get(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        responses: Optional[Dict[int, ResponseSpec]] = None,
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
@@ -655,6 +663,8 @@ class get(HTTPRouteHandler):
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
             response_headers: A string keyed dictionary mapping [ResponseHeader][starlite.datastructures.ResponseHeader]
                 instances.
+            responses: A dictionary of additional status codes and a description of their expected content.
+                This information will be included in the OpenAPI schema
             status_code: An http status code for the response. Defaults to '200'.
             sync_to_thread: A boolean dictating whether the handler function will be executed in a worker thread or the
                 main event loop. This has an effect only for sync handler functions. See using sync handler functions.
@@ -697,6 +707,7 @@ class get(HTTPRouteHandler):
             response_cookies=response_cookies,
             response_description=response_description,
             response_headers=response_headers,
+            responses=responses,
             security=security,
             status_code=status_code,
             summary=summary,
@@ -738,6 +749,7 @@ class post(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        responses: Optional[Dict[int, ResponseSpec]] = None,
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
@@ -776,6 +788,8 @@ class post(HTTPRouteHandler):
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
             response_headers: A string keyed dictionary mapping [ResponseHeader][starlite.datastructures.ResponseHeader]
                 instances.
+            responses: A dictionary of additional status codes and a description of their expected content.
+                This information will be included in the OpenAPI schema
             status_code: An http status code for the response. Defaults to '201' for 'POST'.
             sync_to_thread: A boolean dictating whether the handler function will be executed in a worker thread or the
                 main event loop. This has an effect only for sync handler functions. See using sync handler functions.
@@ -818,6 +832,7 @@ class post(HTTPRouteHandler):
             response_cookies=response_cookies,
             response_description=response_description,
             response_headers=response_headers,
+            responses=responses,
             security=security,
             status_code=status_code,
             summary=summary,
@@ -859,6 +874,7 @@ class put(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        responses: Optional[Dict[int, ResponseSpec]] = None,
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
@@ -897,6 +913,8 @@ class put(HTTPRouteHandler):
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
             response_headers: A string keyed dictionary mapping [ResponseHeader][starlite.datastructures.ResponseHeader]
                 instances.
+            responses: A dictionary of additional status codes and a description of their expected content.
+                This information will be included in the OpenAPI schema
             status_code: An http status code for the response. Defaults to '200'.
             sync_to_thread: A boolean dictating whether the handler function will be executed in a worker thread or the
                 main event loop. This has an effect only for sync handler functions. See using sync handler functions.
@@ -939,6 +957,7 @@ class put(HTTPRouteHandler):
             response_cookies=response_cookies,
             response_description=response_description,
             response_headers=response_headers,
+            responses=responses,
             security=security,
             status_code=status_code,
             summary=summary,
@@ -980,6 +999,7 @@ class patch(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        responses: Optional[Dict[int, ResponseSpec]] = None,
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
@@ -1018,6 +1038,8 @@ class patch(HTTPRouteHandler):
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
             response_headers: A string keyed dictionary mapping [ResponseHeader][starlite.datastructures.ResponseHeader]
                 instances.
+            responses: A dictionary of additional status codes and a description of their expected content.
+                This information will be included in the OpenAPI schema
             status_code: An http status code for the response. Defaults to '200'.
             sync_to_thread: A boolean dictating whether the handler function will be executed in a worker thread or the
                 main event loop. This has an effect only for sync handler functions. See using sync handler functions.
@@ -1060,6 +1082,7 @@ class patch(HTTPRouteHandler):
             response_cookies=response_cookies,
             response_description=response_description,
             response_headers=response_headers,
+            responses=responses,
             security=security,
             status_code=status_code,
             summary=summary,
@@ -1101,6 +1124,7 @@ class delete(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        responses: Optional[Dict[int, ResponseSpec]] = None,
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
@@ -1139,6 +1163,8 @@ class delete(HTTPRouteHandler):
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
             response_headers: A string keyed dictionary mapping [ResponseHeader][starlite.datastructures.ResponseHeader]
                 instances.
+            responses: A dictionary of additional status codes and a description of their expected content.
+                This information will be included in the OpenAPI schema
             status_code: An http status code for the response. Defaults to '204'.
             sync_to_thread: A boolean dictating whether the handler function will be executed in a worker thread or the
                 main event loop. This has an effect only for sync handler functions. See using sync handler functions.
@@ -1181,6 +1207,7 @@ class delete(HTTPRouteHandler):
             response_cookies=response_cookies,
             response_description=response_description,
             response_headers=response_headers,
+            responses=responses,
             security=security,
             status_code=status_code,
             summary=summary,
